@@ -15,12 +15,6 @@ use std::error::Error;
 fn main() -> Result<(), Box<dyn Error>> {
     pyo3_build_config::add_extension_module_link_args();
 
-    // Pass the `perspective_client` links metadata flag so that the `inherit_docs`
-    // macro can find the path to the docs.
-    if let Ok(x) = std::env::var("DEP_PERSPECTIVE_CLIENT_DOCS_PATH") {
-        println!("cargo:rustc-env=PERSPECTIVE_CLIENT_DOCS_PATH={}", x);
-    }
-
     if std::option_env!("PSP_DISABLE_CPP").is_some() {
         return Ok(());
     }
